April 28, 2019.
Boston, MA.

# Structure of SayTeX+

I will use the layering approach outlined in the blog post from April 1.

`compiler.py`: Contains the `Saytex` class which is the main entry point for converting between natural language and LaTeX.

`config.py`: Contains all necessary configuration constants. Note that it does not contain the definition of the language itself, which is implicit everywhere?